@@ -24,21 +24,20 @@ import sys
 
 __docformat__ = "restructuredtext"
 
-# Export some functions
+# Export various things from the modules
 from xdis.version_info import *
 
 from xdis.bytecode import (
     Bytecode,
-    Instruction,
-    extended_arg_val,
-    get_jump_targets,
-    instruction_size,
     list2bytecode,
     next_offset,
     op_has_argument,
-    op_size
     )
 
+from xdis.instruction import (
+    Instruction,
+)
+
 from xdis.codetype import (
     Code13,
     Code15,
@@ -50,6 +49,20 @@ from xdis.codetype import (
     iscode,
 )
 
+from xdis.cross_dis import (
+    code_info,
+    extended_arg_val,
+    findlinestarts,
+    findlabels,
+    format_code_info,
+    get_code_object,
+    get_jump_target_maps,
+    instruction_size,
+    pretty_flags as pretty_code_flags,
+    op_size,
+    show_code,
+)
+
 from xdis.load import (
     is_pypy,
     load_file,
