@@ -260,7 +260,9 @@ add_magic_from_int(3390, "3.7.0alpha0")
 add_magic_from_int(3391, "3.7.0alpha3")
 add_magic_from_int(
     3392, "3.7.0beta2"
-)  # PEP 552 - Additional word in header and possibly no timestamp
+)  # Initial PEP 552 - Additional word in header and possibly no timestamp
+
+# Final PEP 552: timestamp + size field or no timestamp + SipHash
 add_magic_from_int(3393, "3.7.0beta3")
 add_magic_from_int(3394, "3.7.0")
 add_magic_from_int(3401, "3.8.0a3+")
@@ -313,7 +315,7 @@ add_canonic_versions(
     "2.7.8 2.7.9 2.7.10 2.7.11 2.7.12 2.7.13 2.7.14 2.7.15 "
     "2.7.15candidate1 "
     "2.7.16 "
-    "2.7.17rc1 2.7.17candidate1 2.7.17",
+    "2.7.17rc1 2.7.17candidate1 2.7.17 2.7.18",
     "2.7",
 )
 add_canonic_versions("3.0 3.0.0 3.0.1", "3.0a5")
@@ -325,7 +327,7 @@ add_canonic_versions(
 add_canonic_versions(
     "3.4 3.4.0 3.4.1 3.4.2 3.4.3 3.4.4 3.4.5 3.4.6 3.4.7 3.4.8 3.4.9 3.4.10", "3.4rc2"
 )
-add_canonic_versions("3.5.0 3.5.1", "3.5")
+add_canonic_versions("3.5 3.5.0 3.5.1", "3.5")
 add_canonic_versions("3.5.2 3.5.3 3.5.4 3.5.5 3.5.6 3.5.7 3.5.8 3.5.9", "3.5.2")
 add_canonic_versions(
     "3.6b2 3.6 3.6.0 3.6.1 3.6.2 3.6.3 3.6.4 3.6.5 3.6.6 3.6.7 3.6.8 3.6.9 3.6.10", "3.6rc1"
@@ -366,7 +368,7 @@ def magic_int2float(magic_int):
     return py_str2float(magicint2version[magic_int])
 
 
-def py_str2float(version):
+def py_str2float(orig_version):
     """Convert a Python version into a two-digit 'canonic' floating-point number,
     e.g. 2.5, 3.6.
 
@@ -376,8 +378,7 @@ def py_str2float(version):
     point number. For example 3.2a1, 3.2.0, 3.2.2, 3.2.6 among others all map to
     3.2.
     """
-    if version.endswith("pypy"):
-        version = version[: -len("pypy")]
+    version = re.sub(r"(pypy|dropbox)$", "", orig_version)
     if version in magics:
         magic = magics[version]
         for v, m in list(magics.items()):
@@ -400,7 +401,7 @@ def py_str2float(version):
                     pass
                 pass
             pass
-    raise RuntimeError("Can't find a valid Python version for version %s" % version)
+    raise RuntimeError("Can't find a valid Python version for version %s" % orig_version)
     return
 
 
