@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2018 by Rocky Bernstein
+# Copyright (c) 2016-2018, 2020 by Rocky Bernstein
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -30,22 +30,24 @@ want to run on Python 2.7.
 # imports so this can run on older Pythons. This is
 # intended to be a more cross-version Python program
 
-import datetime, re, sys
+import datetime, re, sys, types
 from collections import deque
 
 import xdis
 
 from xdis import IS_PYPY
 from xdis.bytecode import Bytecode
-from xdis.codetype import iscode, to_portable
+from xdis.codetype import iscode, codeType2Portable
 from xdis.load import check_object_path, load_module
-from xdis.util import format_code_info
+from xdis.cross_dis import format_code_info
 from xdis.version import VERSION
 from xdis.op_imports import op_imports
 
 
 def get_opcode(version, is_pypy):
     # Set up disassembler with the right opcodes
+    if type(version) in (list, tuple):
+        version = ".".join([str(x) for x in version])
     lookup = str(version)
     if is_pypy:
         lookup += "pypy"
@@ -66,6 +68,7 @@ def show_module_header(
     is_pypy=False,
     magic_int=None,
     source_size=None,
+    sip_hash=None,
     header=True,
     show_filename=True,
 ):
@@ -99,12 +102,14 @@ def show_module_header(
                 "\n# ".join(sys.version.split("\n")),
             )
         )
-    if timestamp > 0:
+    if timestamp is not None:
         value = datetime.datetime.fromtimestamp(timestamp)
         real_out.write("# Timestamp in code: %d" % timestamp)
         real_out.write(value.strftime(" (%Y-%m-%d %H:%M:%S)\n"))
-    if source_size:
+    if source_size is not None:
         real_out.write("# Source code size mod 2**32: %d bytes\n" % source_size)
+    if sip_hash is not None:
+        real_out.write("# SipHash:           0x%x\n" % sip_hash)
     if show_filename:
         real_out.write("# Embedded file name: %s\n" % co.co_filename)
 
@@ -117,6 +122,7 @@ def disco(
     is_pypy=False,
     magic_int=None,
     source_size=None,
+    sip_hash=None,
     header=True,
     asm_format=False,
     show_bytes=False,
@@ -136,6 +142,7 @@ def disco(
         is_pypy,
         magic_int,
         source_size,
+        sip_hash,
         header,
         show_filename=False,
     )
@@ -194,14 +201,18 @@ def disco_loop_asm_format(opc, version, co, real_out, fn_name_map, all_fns):
     use more stack space at runtime.
     """
 
-    co = to_portable(co)
+    co = codeType2Portable(co)
     co_name = co.co_name
     mapped_name = fn_name_map.get(co_name, co_name)
 
     new_consts = []
     for c in co.co_consts:
         if iscode(c):
-            c_compat = to_portable(c)
+            if isinstance(c, types.CodeType):
+                c_compat = codeType2Portable(c)
+            else:
+                c_compat = c
+
             disco_loop_asm_format(
                 opc, version, c_compat, real_out, fn_name_map, all_fns
             )
@@ -258,7 +269,7 @@ def disassemble_file(
     try to find the corresponding compiled object.
     """
     filename = check_object_path(filename)
-    version, timestamp, magic_int, co, is_pypy, source_size = load_module(filename)
+    version, timestamp, magic_int, co, is_pypy, source_size, sip_hash = load_module(filename)
 
     if header:
         show_module_header(
@@ -269,6 +280,7 @@ def disassemble_file(
             is_pypy,
             magic_int,
             source_size,
+            sip_hash,
             show_filename=True,
         )
 
@@ -281,11 +293,12 @@ def disassemble_file(
             is_pypy,
             magic_int,
             source_size,
+            sip_hash,
             asm_format=asm_format,
             show_bytes=show_bytes,
         )
     # print co.co_filename
-    return filename, co, version, timestamp, magic_int
+    return filename, co, version, timestamp, magic_int, is_pypy, source_size, sip_hash
 
 
 def _test():
