@@ -334,6 +334,8 @@ class _Marshaller:
     def dump_code3(self, x):
         self._write(TYPE_CODE)
         self.w_long(x.co_argcount)
+        if hasattr(x, "co_posonlyargcount"):
+            self.w_long(x.co_posonlyargcount)
         self.w_long(x.co_kwonlyargcount)
         self.w_long(x.co_nlocals)
         self.w_long(x.co_stacksize)
@@ -1044,7 +1046,14 @@ def dumps(x, version=version, python_version=None):
                 buf.append(b)
         return b"".join(buf)
     else:
-        return "".join(buffer)
+        buf = []
+        for b in buffer:
+            if isinstance(b, bytes):
+                buf.append(b.decode())
+            else:
+                buf.append(b)
+
+        return "".join(buf)
 
 
 @builtinify
