@@ -1,4 +1,4 @@
-# (C) Copyright 2017, 2019 by Rocky Bernstein
+# (C) Copyright 2017, 2019-2020 by Rocky Bernstein
 """
 CPython 3.0 bytecode opcodes
 
@@ -34,11 +34,15 @@ rm_op(l, 'MAP_ADD',              147)
 # changes, these have to be applied *after* removing ops (with
 # the same name).
 
-def_op(l, 'SET_ADD',        17,  1, 0)
-def_op(l, 'LIST_APPEND',    18,  2, 1)
+#          OP NAME            OPCODE POP PUSH
+#--------------------------------------------
 
-jrel_op(l, 'JUMP_IF_FALSE', 111, 1, 1)
-jrel_op(l, 'JUMP_IF_TRUE',  112, 1, 1)
+def_op(l, 'SET_ADD',              17, 2, 0)  # Calls set.add(TOS1[-i], TOS).
+                                             # Used to implement set comprehensions.
+def_op(l, 'LIST_APPEND',          18, 2, 0)  # Calls list.append(TOS1, TOS).
+                                             # Used to implement list comprehensions.
+jrel_op(l, 'JUMP_IF_FALSE',      111, 1, 1)
+jrel_op(l, 'JUMP_IF_TRUE',       112, 1, 1)
 
 # Yes, pj2 not pj3 - Python 3.0 is more like 2.7 here with its
 # JUMP_IF rather than POP_JUMP_IF.
